function terrplotl(qmethod,sol,eldata,evt,xy,x,y,figno,axis_value)
%TERRPLOTL   plots solution and error estimate on L-shaped domain
%terrplotl(qmethod,sol,eldata,evt,xy,x,y,figno)
%   input
%          qmethod    approximation method
%          sol        nodal solution vector 
%          eldata     element error vector
%          evt        element mapping matrix
%          xy         vertex coordinate vector  
%          x          vector of x-axis interpolation points
%          y          vector of y-axis interpolation points
%          figno      figure number
%          axis_value axis for plotting
%    TIFISS function: QL; 3 March 2011, DJS; 16 August 2019
% Copyright (c) 2011 D.J. Silvester and Qifeng Liao

if nargin<9, axis_value=[min(x),max(x),min(y),max(y)]; end

if figno==0, return, end
fprintf('plotting solution and the estimated error\n')
fprintf('... this might be a little slow ...')
if qmethod==2
    ev=evt(:,1:3);
else
    ev=evt;
end
% interpolate to a cartesian product mesh
[X,Y]=meshgrid(x,y);
xysol = griddata(xy(:,1),xy(:,2),sol,X,Y);
[II,JJ]=find(X<0 & Y<0); xysol(II,JJ)=nan;
figure(figno)
%subplot(121),contour(X,Y,xysol,20),axis('square')
subplot(121),trimesh(evt(:,1:3),xy(:,1),xy(:,2),sol), axis(axis_value,'square')
title(['solution with P',num2str(qmethod),' approximation'])
%%
xx=xy(:,1); yy=xy(:,2);
nel=length(eldata);
% loop over elements    
for ielem = 1:nel
xl = xx(ev(ielem,:));
yl = yy(ev(ielem,:)); 
xc(ielem,1) = (1/3)*sum(xl);
xc(ielem,2) = (1/3)*sum(yl);
end
%
% interpolate to a cartesian product mesh
x=0.5*(x(1:end-1)+x(2:end));
y=0.5*(y(1:end-1)+y(2:end));
[X,Y]=meshgrid(x,y);
xysol = griddata(xc(:,1),xc(:,2),eldata,X,Y);
[II,JJ]=find(X<0 & Y<0); xysol(II,JJ)=nan;
%subplot(122),contour(X,Y,xysol,40),axis('square')
subplot(122),surfc(X,Y,xysol),axis('square')
title('estimated error')
%subplot(111)
fprintf('done\n')
return
